"""
message.py

Created by Stephen Andrews, October 25th, 2018.
"""

from sqlalchemy import desc

from app.extensions import AuditMixin, db
from .user import User
from .listing import Listing


class Thread(db.Model, AuditMixin):
    """The model for a thread."""
    __tablename__ = 'thread'


    id = db.Column(db.Integer, primary_key=True)
    from_user = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)
    to_user = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)
    
    def serialize(self):
        j = {}
        last_message = Message.query.filter_by(thread_id=self.id).order_by(desc(Message.id)).first()
        
        j['id'] = self.id
        j['from_user'] = User.query.filter_by(id=self.from_user).first().serialize()
        j['to_user'] = User.query.filter_by(id=self.to_user).first().serialize()
        j['last_message'] = last_message.serialize() if last_message else ''
        j['updated'] = last_message.updated if last_message else ''

        return j

class Message(db.Model, AuditMixin):
    """The model for a message."""
    __tablename__ = 'message'

    id = db.Column(db.Integer, primary_key=True)
    thread_id = db.Column(db.Integer, db.ForeignKey('thread.id'), nullable=False)
    message = db.Column(db.Text)
    read = db.Column(db.Boolean, default=False)
    sent_by = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)
    is_request = db.Column(db.Boolean, server_default='f', default=False, nullable=False)

    def serialize(self):
        j = {}
        j['id'] = self.id
        j['message'] = self.message
        j['read'] = self.read
        j['sent_by'] = self.sent_by
        j['sent'] = self.created
        j['is_request'] = self.is_request
        j['created'] = self.created

        if self.is_request:
            try:
                j['listing'] = Listing.query.filter_by(id=int(self.message)).first().serialize()
            except:
                j['listing'] = {}
        return j
