"""
transaction.py

Represents a transaction.

Created by Stephen Andrews, December 6th, 2018.
"""

import maya
from sqlalchemy.orm import relationship

from app.extensions import AuditMixin, db


class Transaction(db.Model, AuditMixin):
    """The model for a transaction."""
    __tablename__ = 'transaction'

    id = db.Column(db.Integer, primary_key=True)
    listing_id = db.Column(db.Integer, db.ForeignKey('listing.id'), nullable=False)
    buyer_id = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)
    status = db.Column(db.Integer, db.ForeignKey('status.id'), nullable=False)

    buyer = relationship('User', primaryjoin='Transaction.buyer_id == User.id')
    listing = relationship('Listing', primaryjoin='Transaction.listing_id == Listing.id')

    def serialize(self):
        j = {}
        j['listing'] = self.listing.serialize()
        j['buyer'] = self.buyer.serialize()
        j['status'] = self.status
        j['created'] = self.created
        j['slang_created'] = maya.parse(self.created).slang_time()
        j['id'] = self.id

        return j