"""
user.py

Created by Stephen Andrews, September 19th, 2018.
"""

from flask_login import UserMixin, AnonymousUserMixin

from app.config import Config
from app.extensions import AuditMixin, db


class User(db.Model, AuditMixin, UserMixin):
    """The Model for a User."""
    __tablename__ = 'user'

    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.Text, nullable=False, unique=True)
    password = db.Column(db.LargeBinary, nullable=False)
    university_id = db.Column(db.Integer, db.ForeignKey('university.id'), nullable=False)
    email = db.Column(db.Text, nullable=False, unique=True)
    session_id = db.Column(db.Text, nullable=False, unique=True)
    expo_token = db.Column(db.Text)
    profile_picture = db.Column(db.Text)

    def __repr__(self):
        representation = "<User {} - Username: {}, Password: {}, Uni ID: {}, Email: {}, Profile Pictue: {}>"
        return representation.format(self.id, self.username, self.password,self.university_id, self.email, self.profile_picture)

    def serialize(self):
        j = {}
        j['user_id'] = self.id
        j['username'] = self.username
        j['university_id'] = self.university_id
        j['email'] = self.email
        j['session_id'] = self.session_id
        j['expo_token'] = self.expo_token
        j['profile_picture'] = self.profile_picture

        return j


class Guest(AnonymousUserMixin):
    pass
