"""
image.py

API endpoint for uploading an image.

Created by John Bieber, November 23, 2018.
"""
from flask import Blueprint, request

import boto3
image = Blueprint('image', __name__)
s3 = boto3.resource('s3')

from app.utils import verify_session

@image.before_request
def authorize():
    """Require authorization for all views."""
    if not request.headers.get('authorization'):
        return 'unauthorized', 401
    temp = request.headers['authorization'].split(' ')
    if not len(temp) == 2:
        return 'invalid authorization header'
    if not verify_session(temp[1]):
        return 'unauthorized', 401

@image.route('/upload', methods=['POST'])
def post_image():
    print("Attempting to upload a photo")
    payload = request.files
    if not payload:
        return 'No content received', 400

    keys = []

    for key in payload.keys():
        keys += [key]
        s3.Bucket('bookstand').put_object(Key=key, Body=payload[key])

    print("Uploaded images to S3 instance with keys:", keys)

    return 'Received request', 200