"""
test_book.py

Tests API endpoint for books.

Created by Stephen Andrews, September 18th, 2018.
"""

import json
import os

import pytest

from app.models import Author, Book, User, University, VerificationList


ART_OF_SQL = Book(isbn_10='0596008945', isbn_13='9780596008949', publisher='O\'Reilly Media', published_date=2007, title='The Art of SQL')
CRACKING_CODING = Book(isbn_10='0984782850', isbn_13='9780984782857', publisher='Careercup', published_date=2015, title='Cracking the Coding Interview')
VERIFICATION = VerificationList(session_id='1', valid=True)
TEST_USER = User(username='stephen', password=b'C4F8A99346F22B355978F380EF05AFDB44C5DDA26E9DDF8AC31196DFE79C2E3A', university_id=1, email='sandrews@wpi.edu', session_id='1')
WPI = University(university_name='WPI', city='Worcester', state='MA', country='USA', timezone='EST')

@pytest.mark.parametrize('init_database', [[WPI, TEST_USER, VERIFICATION]], indirect=True)
@pytest.mark.parametrize('book', [ART_OF_SQL])
def test_get(test_client, init_database, book):
    """Tests get endpoint for a book."""
    #get the user's session_id
    #put it into the header: Authorization: 'Bearer {}'.format(session_id)

    endpoint = 'book/{}'.format(book.isbn_10)
    response = test_client.get(endpoint, headers={'Authorization': 'Bearer 1'})
    data = json.loads(response.get_data(as_text=True))

    assert data['isbn_10'] == book.isbn_10
    assert data['isbn_13'] == book.isbn_13
    assert data['publisher'] == book.publisher
    assert data['published_date'] == book.published_date
    assert data['title'] == book.title
