"""
test_user.py

Tests API endpoint for users.

Created by Theodore Bieber, October 4th, 2018.
"""

import json
import os

import pytest

from app.models import University, Author, Book, User, VerificationList

ART_OF_SQL = Book(isbn_10='0596008945', isbn_13='9780596008949', description='desc', publisher='O\'Reilly Media', published_date=2007, title='The Art of SQL', thumbnail='', small_thumbnail='')
TEST_USER = User(username='stephen', password=b'C4F8A99346F22B355978F380EF05AFDB44C5DDA26E9DDF8AC31196DFE79C2E3A', university_id=1, email='sandrews@wpi.edu', session_id='1')
WPI = University(university_name='WPI', city='Worcester', state='MA', country='USA', timezone='EST')
VERIFICATION = VerificationList(session_id='1', valid=True)

@pytest.mark.parametrize('init_database', [[WPI, TEST_USER, ART_OF_SQL, VERIFICATION]], indirect=True)
@pytest.mark.parametrize('user, book', [
    (TEST_USER, ART_OF_SQL),
])
def test_add(test_client, init_database, user, book):
    """Test add endpoint."""

    payload = {}
    payload['user_id'] = user.id
    payload['book_id'] = book.id

    response = test_client.post('library/add',
                                data=json.dumps(payload),
                                content_type='application/json',
                                headers={'Authorization': 'Bearer 1'})
    assert response.status_code == 200

@pytest.mark.parametrize('user', [TEST_USER])
def test_get(test_client, init_database, user):
    """Tests get endpoint for getting a users owned books."""
    """Test just the user_id of 1"""
    endpoint = 'library/{}'.format(1) 
    response = test_client.get(endpoint, headers={'Authorization': 'Bearer 1'})

    assert response.status_code == 200