"""
logger.py

Created by Stephen Andrews, March 2017
"""

import logging
import logging.config
import os

CONFIG = {
    'version': 1,
    'formatters': {
        'root': {
            'format': '%(asctime)s %(name)-12s %(levelname)-8s line: %(lineno)s:  %(message)s',
            'datefmt': '%Y-%m-%d %H:%M:%S %Z'
        }
    },
    'root': {
        'level': 'INFO',
        'handlers': ['root']
    },
    'handlers': {
        'root': {
            'class': 'logging.FileHandler',
            'formatter': 'root',
            'level': 'INFO',
            'mode': 'a+'
        }
    }
}

class Logger:
    """
    Super class for logging output.

    All logs can be found in the home directory under /logs.
    """

    def __init__(self, **kwargs):
        base_path = '{}/logs'.format(os.path.expanduser('~'))
        if not os.path.exists(base_path):
            os.mkdir(base_path)

        log_name = kwargs.pop('logfile_name', 'root')
        CONFIG['handlers']['root']['filename'] = "{}/{}.log".format(base_path, log_name)

        logging.config.dictConfig(CONFIG)
        self.logger = logging.getLogger(log_name)

        super().__init__(**kwargs)
