import React, { Component } from 'react';

import {
  View,
  Text,
  Image,
  StyleSheet,
  TouchableOpacity,
} from 'react-native';

/**
 * A card element containing an image.
 * 
 * Usage:
 * ```
 * <ImageCard uri={''} onPress={callback}>
 *  { children }
 * </ImageCard>
 * ```
 * @author Stephen Andrews
 * @since 11.17.18
 */
export default class Card extends Component {

  render() {
    return (
      <TouchableOpacity style={styles.card} onPress={this.props.onPress}>

        {/* Round top corners of image */}
        <View style={{ borderTopLeftRadius: 15, borderTopRightRadius: 15}} overflow='hidden'>
          <Image 
            resizeMode={"cover"}
            style={{width: '100%', height: 150}}
            source={{uri: this.props.uri}} />
        </View>
        
        {/* Card content */}
        <View flex={1} style={{padding: 10}}>
          {this.props.children}
        </View>
      </TouchableOpacity>
    );
  }
}

const styles = StyleSheet.create({
  card: {
    backgroundColor: '#FFFFFF',
    borderRadius: 15,
    flex: 1,
    shadowColor: 'black',
    shadowOffset: {width: 0, height: 0},
    shadowRadius: 5,
    shadowOpacity: 0.10,
    elevation: 5
  },
});
