import React, { Component } from 'react';

import {
  Dimensions,
  View,
  Text,
  Image,
  StyleSheet,
  TouchableOpacity,
} from 'react-native';

import ImageOverlay from './ImageOverlay';

import Carousel, { Pagination } from 'react-native-snap-carousel';

const { width: viewportWidth, height: viewportHeight } = Dimensions.get('window');

/**
 * Image carousel.
 * @author Stephen Andrews
 * @since 11.25.18
 */
export default class ImageCarousel extends Component {

  constructor() {
    super();

    this.state = {
      activeIndex: 0
    }
  }

  /**
   * Translate a percentage to a width in points.
   * @param percentage The width percentage desired.
   * @return The width in points. 
   */
  wp = (percentage) => {
      const value = (percentage * viewportWidth) / 100;
      return Math.round(value);
  }

 

  _renderItem_ (overlays) {
    _renderItem = ({item, index}) => {
      return (
          <View style={styles.slide}>
            <ImageOverlay
              overlay={overlays[index]}
              style={{'width': '100%', 'height': '100%'}}
              source={{uri: item}} />
          </View>
      );
    }
    return _renderItem;
  }

  render() {
    return (
      <View>
        <Carousel
          ref={(c) => { this._carousel = c; }}
          data={this.props.photos}
          renderItem={this._renderItem_(this.props.overlays)}
          sliderWidth={this.wp(100)}
          itemWidth={this.wp(100)}
          inactiveSlideOpacity={1}
          inactiveSlideScale={1}
          containerCustomStyle={styles.carousel}
          onSnapToItem={(index) => this.setState({activeIndex: index})}
        />

        <Pagination 
          activeDotIndex={this.state.activeIndex}
          dotsLength={this.props.photos.length}
          dotColor={'rgba(255, 255, 255, 0.92)'}
          dotStyle={styles.paginationDot}
          carouselRef={this._carousel}
          inactiveDotColor="#FFF"
          inactiveDotOpacity={0.4}
          inactiveDotScale={0.6}
          tappableDots={!!this._carousel} 
          containerStyle={{
            position: 'absolute',
            marginLeft: 'auto',
            marginRight: 'auto',
            left: 0,
            right: 0,
            top: 250
          }}/>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  carousel: {
    maxHeight: 300,
  },
  paginationDot: {
    width: 8,
    height: 8,
    borderRadius: 4,
    marginHorizontal: 8,
    shadowColor: 'black',
    shadowOffset: {width: 0, height: 0},
    shadowRadius: 2,
    shadowOpacity: 0.40
  },
  slide: {
    height: 300
  }
});
