import React, {
  Component
} from 'react';
import {
  View,
  Text,
  TouchableOpacity,
  StyleSheet,
} from 'react-native';
import {BarCodeScanner, Permissions} from 'expo';

import API from '../../API';
import * as Constants from '../../Constants';

/**
 * Handles the scanning of barcodes to parse ISBN.
 * @author John Bieber, Stephen Andrews
 */
export default class BarcodeForm extends Component {
  state = {
    hasCameraPermission: null,
    waiting: false
  };

  componentDidMount() {
    this._requestCameraPermission();
  }

    // TODO: Request this during onboarding
  _requestCameraPermission = async () => {
    const { status } = await Permissions.askAsync(Permissions.CAMERA);
    this.setState({
      hasCameraPermission: status === 'granted',
      waiting: false
    });
  };

  _handleBarCodeRead = data => {
    this.finish(data.data);
  };

  finish = (isbn=undefined) => {
    if (isbn) {
      let cb = (response) => {
        return response.json().then((data) => {
          this.props.navigation.navigate(this.props.navigation.state.params.returnScreen, {bookInfo: data});
        }).catch((error) => {
          console.log(error);
        });
      }

      if (!this.state.waiting) {
        this.state.waiting = true;
        API.getBookIDFromISBN(isbn, cb);
      }
    } else {
      this.props.navigation.navigate(this.props.navigation.state.params.returnScreen);
    }
  }

  render() {
    return (
      <View flex={1}>
        {this.state.hasCameraPermission === null ?
          <Text>Requesting for camera permission</Text> :
          this.state.hasCameraPermission === false ?
            <Text>Camera permission is not granted</Text> :
            <BarCodeScanner
              barCodeTypes={[BarCodeScanner.Constants.BarCodeType.ean13]}
              onBarCodeRead={this._handleBarCodeRead}
              style={StyleSheet.absoluteFill}
            />
        }

        <View flexGrow={1} justifyContent='space-between'>
          {/* Top overlay */}
          <View style={styles.alignmentOverlay}>
            <Text style={{color: 'white', fontSize: 14}}>Point the camera at the barcode</Text>
            <Text style={{color: 'white', fontSize: 14}}>The ISBN will be scanned automatically</Text>
          </View>

          {/* Bottom overlay */}
          <View style={styles.alignmentOverlay}>
            <TouchableOpacity style={styles.buttonContainer} onPress={()=>{this.finish()}}>
              <Text style={styles.buttonText}>{"Cancel"}</Text>
            </TouchableOpacity>
          </View>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  alignmentOverlay: {
    alignItems: 'center',
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    justifyContent: 'center',
    width: '100%',
    height: '30%',
  },
  buttonContainer: {
    backgroundColor: Constants.PRIMARY_RED,
    borderRadius: 10,
    padding: 15,
    width: '60%'
  },
  buttonText: {
    color: '#FFF',
    fontSize: 18,
    fontWeight: '500',
    textAlign: 'center'
  }
});
