/**
 * Book selection for the library/bookshelf
 * @author Ted Bieber
 */

import React, {
    Component
  } from 'react';
  import {
    KeyboardAvoidingView,
    View,
    Text,
    StyleSheet,
    TouchableOpacity,
    TextInput,
  } from 'react-native';
  
  import Icon from 'react-native-vector-icons/Feather';

  import BookEntry from '../../components/BookEntry';
  import Header from '../../components/Header';
  import API from '../../API';
  import StorageManager from '../../StorageManager';

  import Search from '../../components/Search';

  import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';

  export default class AddBookToShelfForm extends Component {

    
    state = {
      isbn: undefined,
      fromScanner: false,
      title:"",
    }

     /**
   * Renders a book entry component if the user has scanned a barcode.
   * @returns A book entry component to be rendered.
   */
  renderScan = () => {
    if (this.state.fromScanner) {
      return <View style={{height: 130, marginBottom: 10}}>
              <BookEntry 
                book={this.props.navigation.state.params.bookInfo} 
                style={{height: 130, marginBottom: 10}} />
             </View>
    } else if(this.state.bookSelected) {
      return <View style={{height: 130, marginBottom: 10}}>
              <BookEntry 
                book={this.state.book} 
                style={{height: 130, marginBottom: 10}} />
             </View>
    }
  }

    scanBarcodePressed = () => {
        this.setState({
          isbn: "",
          fromScanner: false,
          title:this.state.title
        });
    
        //@Author Ted - This second parameter I added so we can generalize the Barcode Scanner to be used anywhere, 
        // rather than hard coding in which screen it returns to, we can pass in the name. 
        // This can be improved if we utilize different types of navigators, but for this week this is gonna have to do.
        this.props.navigation.navigate('Barcode', {returnScreen:'AddBookToShelf'});
    }

    componentWillMount() {
      if (this.props.navigation.state.params 
          && this.props.navigation.state.params.bookInfo 
          && this.props.navigation.state.params.bookInfo.isbn_13 
          && (this.state.isbn != this.props.navigation.state.params.bookInfo.isbn_13)) {
        this.setState({
          isbn: this.props.navigation.state.params.bookInfo.isbn_13,
          fromScanner: true,
          title:this.props.navigation.state.params.bookInfo.title
        });
      }
    }

    // TODO: NEED TO HAVE THIS UPDATE THE PROFILE SCREEN OR THE BOOK SHELF SOMEHOW!!!
    onPressConfirm = () => {
      cb = (result) => { 
        this.props.navigation.navigate('Profile', {
          'bookID': (
            this.state.book ?  
              this.state.book.id : this.props.navigation.state.params && this.props.navigation.state.params.bookInfo && this.props.navigation.state.params.bookInfo.id ? 
                this.props.navigation.state.params.bookInfo.id : (this.props.navigation.state.params && this.props.navigation.state.params.previousID ? 
                  this.props.navigation.state.params.previousID : undefined))
        });
      }

      StorageManager.getItem('user_id',
        (result) => {
          if(this.state.fromScanner) {
            API.addOwned(result,this.props.navigation.state.params.bookInfo.id, cb);
          } else if(this.state.book) {
            API.addOwned(result, this.state.book.id, cb);
          } else {
          }
        }
      );
    }

      /**
     * Renders the search component allowing a user to search for a book using autocomplete
     * suggestions or scan a barcode.
     */
    renderSearchField = () => {
      var title = this.state.book != null ? this.state.book.title : "";

      return (
        <View 
          flexDirection="row"
          justifyContent="space-between"
          style={{backgroundColor: '#FFF'}}>

          <TextInput
            autoCapitalize="none"
            autoCorrect={false}
            clearButtonMode="always"
            flexGrow={1}
            maxLength={30}
            onChangeText={(text) => this.setState({isbn:this.state.isbn,fromScanner:false,title: text})}
            placeholder="Book title e.g. The Bible"
            returnKeyType="done"
            style={styles.input}
            text={title}
            value={this.state.title}
            />
          
          {/* Wrap icon in a view to center veritcally within the container */}
          <View justifyContent="center">
            <Icon.Button 
              backgroundColor="transparent"
              color="#4A4A4A"
              name="camera"
              onPress={this.scanBarcodePressed}
              size={35} 
              />
          </View>
        </View>
      );
    }

    /**
     * Callback function used when searching for a book instead of using the barcode scanner.
     * @param data The book object returned by the {@link Search} component.
     */
    searchCallback = (data) => {
      this.setState({
        book: data,
        title: data.title,
        bookSelected: true,
        fromScanner:false,
        isbn:data.isbn_13,
        book: data
      });
    }


    render() {
      const isSearching = this.state.title.length > 0 && !this.state.bookSelected;  

      if (this.props.navigation.state.params 
          && this.props.navigation.state.params.bookInfo 
          && this.props.navigation.state.params.bookInfo.isbn_13 
          && (this.state.isbn != this.props.navigation.state.params.bookInfo.isbn_13)) {
        this.setState({
          isbn: this.props.navigation.state.params.bookInfo.isbn_13,
          fromScanner: true,
          title:this.state.title
        });
      }
      if(isSearching) {
        return (
          <View style={styles.container}>
    
            {/* Don't remove this keyboard view. If this doesn't match up with the above
                function, the keyboard will hide when transitioning views */}
            <KeyboardAwareScrollView keyboardShouldPersistTaps='always' extraHeight={150} enableOnAndroid={true}>
              { this.renderSearchField() }
              <Search searchTerm={this.state.title} onSelect={this.searchCallback} />
            </KeyboardAwareScrollView>
          </View>
        );
      } else {
        return (
          <View style={styles.container}>
            {/* Render book info after its scanned */}
            { this.renderScan() }
            <KeyboardAwareScrollView extraHeight={150} enableOnAndroid={true}>
              
    
              {this.renderSearchField()}
            </KeyboardAwareScrollView>
          
            <View style={{flexDirection: "row"}}>
              <View style={{flex: 1, flexGrow: 1, marginRight: 5}}>
                <TouchableOpacity
                  onPress={()=>{this.props.navigation.navigate('Profile', {'bookID': (this.props.navigation.state.params && this.props.navigation.state.params.previousID ? this.props.navigation.state.params.previousID : undefined)});}}
                  style={[styles.buttonContainer, {marginBottom:15}]}>
                  <Text style={styles.buttonText}>Cancel</Text>
                </TouchableOpacity>
              </View>
    
              <View style={{flex: 1, flexGrow: 1, marginLeft: 5}}>
                <TouchableOpacity
                  onPress={this.onPressConfirm}
                  style={[styles.buttonContainer, {marginBottom:15}]}>
                  <Text style={styles.buttonText}>Confirm</Text>
                </TouchableOpacity>
              </View>
            </View>
          </View>
        );
      }
    }
  }
  
  const styles = StyleSheet.create({
    container: {
      flex: 1,
      padding: 15,
      overflow: 'hidden'
    },
    buttonContainer: {
      backgroundColor: '#4392EF',
      borderRadius: 4,
      height: 50,
      paddingVertical: 12,
      width: '100%'
    },
    buttonText: {
      color: '#FFF',
      fontSize: 18,
      fontWeight: '500',
      textAlign: 'center'
    },
    input: {
      fontSize: 16,
      fontWeight: '500',
      height: 75,
      paddingHorizontal: 10,
      opacity: 1.0,
    },
    label: {
      color: '#464A53',
      fontWeight: '500',
      marginTop: 15,
      textAlign: 'center'
    },
    multilineInput: {
      backgroundColor: '#F2F5F7',
      borderRadius: 4,
      fontSize: 14,
      fontWeight: '500',
      height: 100,
      marginBottom: 15,
      paddingHorizontal: 10,
      opacity: 1.0,
    },
    thumbnailStyle: {
      margin: 5,
      borderRadius: 4,
      width: 75,
      height: 125,
    }
  });
