import React, {
  Component
} from 'react';
import {
  Alert,
  View,
  Text,
  TextInput,
  TouchableOpacity,
  StyleSheet,
  Switch,
} from 'react-native';

import StorageManager from '../../StorageManager';
import API from '../../API';

export default class ForgotForm extends Component {
  constructor() {
    super();
    this.state = {
      email: "",
      switchValue: false,
    };

  }

  /**
   * Makes a call to the API to attempt a login.
   */
  attemptForgot = () => {
    let callback = (response) => {
        this.props.navigation.navigate('Login');
    }

    API.resetUser(this.state.email, callback);
  }

  handleToggleSwitch = () => {
    this.state.switchValue=!this.state.switchValue;
    StorageManager.putItem("remember_me", this.state.switchValue);
    this.forceUpdate();
  }

  /**
   * Updates the login form with the current email.
   * @param email The current email typed.
   */
  updateForm = (email) => {
    this.state.email = email;
  }

  render() {
      return (
        <View style={styles.container}>

          <TextInput
            autoCapitalize="none"
            autoCorrect={false}
            keyboardType="email-address"
            placeholder="Email"
            returnKeyType="next"
            onChangeText={(text) => this.updateForm(text)}
            style={styles.input}
            />

          <TouchableOpacity
            onPress={this.attemptForgot}
            style={styles.buttonContainer}>
            <Text style={styles.buttonText}>Reset Password</Text>
          </TouchableOpacity>
        </View>
      );
    }
}

const styles = StyleSheet.create({
  container: {
    padding: 20,
  },
  buttonContainer: {
    backgroundColor: '#4392EF',
    borderRadius: 4,
    height: 50,
    paddingVertical: 12
  },
  buttonText: {
    color: '#FFF',
    fontSize: 18,
    fontWeight: '500',
    textAlign: 'center'
  },
  input: {
    backgroundColor: '#F2F5F7',
    borderRadius: 4,
    fontSize: 14,
    fontWeight: '500',
    height: 50,
    marginBottom: 15,
    paddingHorizontal: 10,
    opacity: 1.0,
  },
  label: {
    color: '#464A53',
    fontWeight: '500',
    marginTop: 15,
    textAlign: 'center'
  },
  switchview: {
    flexDirection: 'row',
  }
});
