/**
 * List view containing all of the messages for a conversation between two users
 * @author Ted Bieber
 * @since 10.25.2018
 */
import React, { Component } from "react";
import {
  Platform,
  View,
  StyleSheet,
  FlatList,
  ActivityIndicator
} from "react-native";

import API from "../../API";
import Message from "./Message";
import StorageManager from "../../StorageManager";

export default class ConversationListView extends Component {
  constructor() {
    super();

    this.state = {
      isLoading: true,
      messages: [],
      needsReload: true,
      user_id: "",
      pagesLoaded:0,
    };
  }

  loadMessages() {
    let cb = response => {
      return response.json().then(data => {
        this.setState({
          isLoading: false,
          messages: data,
          user_id: this.state.user_id,
          pagesLoaded:1,
        });
      });
    };

    let storagecb = response => {
        this.setState({
            isLoading: this.state.isLoading,
            messages: this.state.messages,
            user_id: response,
            pagesLoaded:1,
        });
        API.getConversation(this.props.conversationId, cb);
    };

    StorageManager.getItem("user_id", storagecb);
  }

  componentDidMount() {
    this.loadMessages();
  }

  componentWillReceiveProps() {
    this.loadMessages(); // pretty sure this updates the messages but not 100% sure
  }

  loadNextPage = () => {
    let cb = (response) => {
      response.json().then((data) => {
        this.setState({
          isLoading: false,
          messages: data.concat(this.state.messages), // add the new messages to the beginning (top) of the list
          needsReload: true,
          user_id: this.state.user_id,
          pagesLoaded:this.state.pagesLoaded+1,
        });
      }, () => {
      });
    }
    // API Call, ask for pages loaded+1
    if(!this.state.isLoading){
      API.getConversation(this.props.conversationId, cb, this.state.pagesLoaded+1);
      this.state.isLoading = true;
    }
  }

  render() {
    {/* Show loading indicator until API returns response */}
    if (this.state.isLoading) {
      return (
        <View style={{ flex: 1, justifyContent: "center" }}>
          <ActivityIndicator />
        </View>
      );
    }

    return (
      <View style={styles.container}>
        <FlatList
          data={this.state.messages.slice()} // This reverses the list of data, so that the messages will render in the correct order
          keyExtractor={(item) => item.id+""}
          renderItem={({ item }) => <Message {...this.props} item={item} user_id={this.state.user_id}/>}
          ref={flatList => { this.flatList = flatList; }}
          onLayout={() => this.flatList.scrollToEnd({animated: true})}
          // style={{  transform: [{ scaleY: -1 }] }} // This inverts the rendering of the list so the real top is at the bottom and the bottom is at the top
          onEndReachedThreshold={0.25} // number of scrollable elements left until threshold is reached 
          // onEndReached={}
          refreshing={false}
          onRefresh={this.loadNextPage}
        />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    marginBottom: 5
  },
  heading: {
    color: "#FFFFFF",
    fontSize: 42,
    fontFamily: Platform.OS === "ios" ? "Helvetica" : "Roboto",
    fontWeight: "500",
    marginBottom: 15,
    marginLeft: 15
  }
});
