import React, {
  Component
} from 'react';

import {
  StyleSheet,
  TouchableOpacity,
  View,
} from 'react-native';

import BookEntry from '../../components/BookEntry';
import HorizontalRule from '../../components/HorizontalRule';

/**
 * An individual list item for the {@link ActiveListings} screen.
 * @author Stephen Andrews
 */
export default class ActiveListingItem extends Component {

  constructor() {
    super();
  }

  /**
   * Navigate to the detailed listing view when a user taps
   * on a listing in their active listings.
   */
  onPressedTouchable = () => {
    this.props.navigation.navigate('DetailedView', {
      'listing': this.props.listing,
      'user_id': this.props.user_id
    });
  }

  render() {
    return (
      <View style={styles.container}>
        <TouchableOpacity
          onPress={() => this.onPressedTouchable()}
          style={styles.touchable}>

          <BookEntry book={this.props.book} />
        </TouchableOpacity>

        <HorizontalRule />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    backgroundColor: '#FDFDFE',
    flexGrow: 1,
  },
  touchable: {
    backgroundColor: '#FFFFFF',
    flexDirection: 'row',
    padding: 5,
  },
});
