import React, { Component } from 'react';

import {
  Modal,
  Platform,
  View,
  StyleSheet,
  Text,
  TouchableOpacity,
  TextInput,
  Alert
} from 'react-native';

import Icon from 'react-native-vector-icons/Feather';

import API from "../../API";

/**
 * Contains layout for the filter modal used in the {@link Profile} screen.
 * @author John Bieber
 */
export default class ChangePasswordModal extends Component {

  constructor() {
    super();

    this.state = {
      oldPassword: "",
      newPassword: "",
      newPasswordConfirm: ""
    }
  }

  /**
   * Renders the header section containing the title and close button.
   */
  renderHeader = () => {
    return (
      <View style={styles.header}>
        <Text style={styles.heading}>Change Password</Text>

        {/* This needs to be after the text element due to absolute positioning.
            Otherwise, you won't be able to click the button. */}
        <TouchableOpacity 
          onPress={this.props.onPress}
          style={styles.dismissButton}>

          <Icon name="x" color="#FFF" size={30} />
        </TouchableOpacity>
      </View>
    );
  }

  /**
   * Begins the start of a new section with the specified name.
   */
  renderSectionHeader = (name) => {
    return (
      <View flexDirection="row" alignItems="center" marginTop={25}>
        <Text style={styles.sectionHeading}>{name}</Text>
        <View style={{
          backgroundColor: '#FFF',
          marginLeft: 20,
          flex: 1,
          height: 1,
          opacity: .30
        }} />
      </View>
    );
  }

  tryChangePassword = () => {
    if(this.state.newPassword === this.state.newPasswordConfirm){
      API.changePassword(this.props.state.username, this.state.oldPassword, this.state.newPasswordConfirm, (result)=>{
        if(result.status == 200){
          Alert.alert('Password changed.', '', [{text: 'Ok', onPress: ()=>{this.props.onPress()}}] );
        }else{
          Alert.alert(result._bodyText);
        }
      });
    }else{
      Alert.alert("New password field does not match the new password confirmation field.");
    }
  }
  
  render() {
    return (
      <Modal
        animationType="slide"
        transparent={true}
        visible={this.props.visible}>

        <View style={styles.container}>
          { this.renderHeader() }
          <View style={styles.contentContainer}>
            { this.renderSectionHeader('Verify Old Password') }
            <TextInput
            secureTextEntry
            autoCapitalize="none"
            autoCorrect={false}
            placeholder="Old Password"
            returnKeyType="next"
            onChangeText={(text) => this.state.oldPassword = text}
            onSubmitEditing={() => this.newPasswordInput.focus()}
            style={styles.input}
            />
            { this.renderSectionHeader('Set New Password') }
            <TextInput
            secureTextEntry
            autoCapitalize="none"
            autoCorrect={false}
            placeholder="New password"
            returnKeyType="next"
            onChangeText={(text) => this.state.newPassword = text}
            onSubmitEditing={() => this.newPasswordInputConfirm.focus()}
            style={styles.input}
            ref={(input) => this.newPasswordInput = input}
            />
            <TextInput
            secureTextEntry
            autoCapitalize="none"
            autoCorrect={false}
            placeholder="Confirm new password"
            returnKeyType="next"
            onChangeText={(text) => this.state.newPasswordConfirm = text}
            style={styles.input}
            ref={(input) => this.newPasswordInputConfirm = input}
            />
          </View>
          <TouchableOpacity 
            onPress={this.tryChangePassword}
            style={styles.confirmButton}>
            <Text style={styles.confirmButtonText}>Confirm</Text>
          </TouchableOpacity>
        </View>
      </Modal>
    );
  }
}

const styles = StyleSheet.create({
  input: {
    marginTop: 5,
    paddingLeft: 10,
    backgroundColor: '#FFF',
    color: '#f75555'
  },
  container: {
    flex: 1,
    backgroundColor: '#f75555'
  },
  contentContainer: {
    flex: 1,
    margin: 30
  },
  confirmButton: {
    backgroundColor: '#FFF',
    height: 75,
    padding: 25
  },
  confirmButtonText: {
    color: '#f75555',
    fontSize: 14,
    fontWeight: '700',
    textAlign: 'center'
  },
  dismissButton: {
    position: 'absolute',
    left: 20
  },
  header: {
    height: 100,
    justifyContent: 'flex-end',
  },
  heading: {
    color: '#FFF',
    fontSize: 24,
    fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
    fontWeight: 'bold',
    textAlign: 'center'
  },
  sectionHeading: {
    color: '#FFFFFF',
    fontSize: 14,
    fontWeight: '700',
    opacity: .70
  }
});
