import React, {
  Component
} from 'react';
import {
  Alert,
  View,
  Text,
  TextInput,
  TouchableOpacity,
  StyleSheet,
} from 'react-native';

import API from '../../API';
import StorageManager from '../../StorageManager';

export default class RegisterForm extends Component {
  constructor() {
    super();
    this.state = {
      email: "",
      username: "",
      password: "",
      confirmPassword: ""
    };
  }

  /**
   * Makes a call to the API to attempt a login.
   */
  attemptRegister = () => {
    let callback = (response) => {
      if (response.status == 200) {
        StorageManager.getItem('user_id', (result) => {
          
          this.props.navigation.navigate('Login');
        }, ()=> {
          console.log('User does not currently have a user_id in storage.');
          this.props.navigation.navigate('Login');
        });
        
      } else {
        console.log(response)
        Alert.alert("Error registering: Username or email has already been taken");
      }
    }

    if (this.state.password != this.state.confirmPassword) {
      Alert.alert("Passwords must match!");
      return;
    }

    if (this.validateEmail(this.state.email)) {
      if (this.validateWPI(this.state.email)) {
        API.registerUser(this.state.username, this.state.password, 1, this.state.email, callback);
      } else {
        alert("We are only accepting signups from WPI students at this time. We'll let you know as soon as Bookstand becomes available at your University!");
      }
    } else {
      alert("Invalid email address");
    }
    
  }

  // validate that it is a proper email format
  validateEmail = (email) => {
    if (/^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/.test(email)){
      return (true);
    }
    return (false);
  }

  /**
   * Prevents users without an @wpi.edu domain from register and
   * captures the email for later use.
   * @param email The email being used to register.
   */
  validateWPI = (email) => {
    let expectedTag = '@wpi.edu';
    let enteredTag = email.substring(email.length - expectedTag.length, email.length);

    if (enteredTag !== expectedTag) {
        API.addInterested(email, (response) => {
          //console.log(response);
        });
        return false
    }

    return true;
  }

  /**
   * Updates the login form with the current username and password.
   * @param username The current username typed.
   * @param password The current password typed.
   */
  render() {
    return (
      <View style={styles.container}>
        <TextInput
          autoCapitalize="none"
          autoCorrect={false}
          placeholder="Username"
          returnKeyType="next"
          onChangeText={(text) => this.state.username = text}
          onSubmitEditing={() => this.emailInput.focus()}
          style={styles.input}
          />

        <TextInput
          autoCapitalize="none"
          autoCorrect={false}
          keyboardType="email-address"
          placeholder="Email"
          returnKeyType="next"
          onChangeText={(text) => this.state.email = text}
          onSubmitEditing={() => this.passwordInput.focus()}
          ref={(input) => this.emailInput = input}
          style={styles.input}
          />

        <TextInput
          placeholder="Password"
          returnKeyType="next"
          onChangeText={(text) => this.state.password = text}
          onSubmitEditing={() => this.confirmPasswordInput.focus()}
          secureTextEntry
          style={styles.input}
          ref={(input) => this.passwordInput = input}
          />

        <TextInput
          placeholder="Confirm Password"
          returnKeyType="go"
          onChangeText={(text) => this.state.confirmPassword = text}
          secureTextEntry
          style={styles.input}
          ref={(input) => this.confirmPasswordInput = input}
          />

        <TouchableOpacity
          onPress={this.attemptRegister}
          style={styles.buttonContainer}>
          <Text style={styles.buttonText}>Register</Text>
        </TouchableOpacity>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    padding: 20,
  },
  buttonContainer: {
    backgroundColor: '#4392EF',
    borderRadius: 4,
    height: 50,
    paddingVertical: 12
  },
  buttonText: {
    color: '#FFF',
    fontSize: 18,
    fontWeight: '500',
    textAlign: 'center'
  },
  input: {
    backgroundColor: '#F2F5F7',
    borderRadius: 4,
    fontSize: 14,
    fontWeight: '500',
    height: 50,
    marginBottom: 15,
    paddingHorizontal: 10,
    opacity: 1.0,
  },
  label: {
    color: '#464A53',
    fontWeight: '500',
    marginTop: 15,
    textAlign: 'center'
  }
});
