import React, {
  Component
} from 'react';
import {
  Alert,
  Keyboard,
  View,
  Text,
  TextInput,
  TouchableOpacity,
  StyleSheet,
  Image,
} from 'react-native';


import API from '../../API';
import BookEntry from '../../components/BookEntry';

export default class SelectBookForm extends Component {
  state = {
    isbn: undefined,
    fromScanner: false
  }

  constructor(){
    super();
  }

  isbnInputChanged = (text) => {
    text = (text.length > 13 ? text.substring(0,13) : text);
    if(this.props.navigation.state.params && this.props.navigation.state.params.bookInfo){
      this.props.navigation.state.params.bookInfo.isbn_13 = text;
    }
    this.setState({isbn: text, fromScanner: false});
  }

  scanBarcodePressed = () => {
    this.setState({
      isbn: "",
      fromScanner: false
    });

    //@Author Ted - This second parameter I added so we can generalize the Barcode Scanner to be used anywhere, 
    // rather than hard coding in which screen it returns to, we can pass in the name. 
    // This can be improved if we utilize different types of navigators, but for this week this is gonna have to do.
    this.props.navigation.navigate('Barcode', {returnScreen:'SelectBook'});
  }

  /**
   * Renders a book entry component if the user has scanned a barcode.
   * @returns A book entry component to be rendered.
   */
  renderScan = () => {
    if (this.state.fromScanner) {
      return <View style={{height: 130, marginBottom: 10}}>
              <BookEntry 
                book={this.props.navigation.state.params.bookInfo} 
                style={{height: 130, marginBottom: 10}} />
             </View>
    }
  }

  componentWillMount() {
    if (this.props.navigation.state.params 
        && this.props.navigation.state.params.bookInfo 
        && this.props.navigation.state.params.bookInfo.isbn_13 
        && (this.state.isbn != this.props.navigation.state.params.bookInfo.isbn_13)) {
      this.setState({
        isbn: this.props.navigation.state.params.bookInfo.isbn_13,
        fromScanner: true
      });
    }
  }

  render() {
    if (this.props.navigation.state.params 
        && this.props.navigation.state.params.bookInfo 
        && this.props.navigation.state.params.bookInfo.isbn_13 
        && (this.state.isbn != this.props.navigation.state.params.bookInfo.isbn_13)) {
      this.setState({
        isbn: this.props.navigation.state.params.bookInfo.isbn_13,
        fromScanner: true
      });
    }

    return (
      <View style={styles.container}>
        {/* Render book info after its scanned */}
        <View style={{flex: 1}}>
          {/* <TextInput
            autoCapitalize="none"
            autoCorrect={false}
            placeholder="ISBN"
            returnKeyType="go"
            value={this.state.isbn}
            onChangeText={(text) => {this.isbnInputChanged(text);}}
            style={styles.input}
            /> */}
          
          <TouchableOpacity
            onPress={()=>{this.scanBarcodePressed();}}
            style={[styles.buttonContainer, {marginBottom:15}]}>
            <Text style={styles.buttonText}>Scan Barcode</Text>
          </TouchableOpacity>

          <TouchableOpacity
            onPress={()=>{this.props.navigation.navigate('Search', {returnScreen: 'SelectBook'});}}
            style={[styles.buttonContainer, {marginBottom:15}]}>
            <Text style={styles.buttonText}>Search for my Book</Text>
          </TouchableOpacity>
          { this.renderScan() }
        </View>

        <View style={{flexDirection: "row"}}>
          <View style={{flex: 1, flexGrow: 1, marginRight: 5}}>
            <TouchableOpacity
              onPress={()=>{this.props.navigation.navigate('CreateListing', {'bookID': (this.props.navigation.state.params && this.props.navigation.state.params.previousID ? this.props.navigation.state.params.previousID : undefined)});}}
              style={[styles.buttonContainer, {marginBottom:15}]}>
              <Text style={styles.buttonText}>Cancel</Text>
            </TouchableOpacity>
          </View>

          <View style={{flex: 1, flexGrow: 1, marginLeft: 5}}>
            <TouchableOpacity
              onPress={()=>{this.props.navigation.navigate('CreateListing', {'bookID': (this.props.navigation.state.params && this.props.navigation.state.params.bookInfo && this.props.navigation.state.params.bookInfo.id ? this.props.navigation.state.params.bookInfo.id : (this.props.navigation.state.params && this.props.navigation.state.params.previousID ? this.props.navigation.state.params.previousID : undefined))});}}
              style={[styles.buttonContainer, {marginBottom:15}]}>
              <Text style={styles.buttonText}>Confirm</Text>
            </TouchableOpacity>
          </View>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    padding: 15,
    overflow: 'hidden'
  },
  buttonContainer: {
    backgroundColor: '#4392EF',
    borderRadius: 4,
    height: 50,
    paddingVertical: 12,
    width: '100%'
  },
  buttonText: {
    color: '#FFF',
    fontSize: 18,
    fontWeight: '500',
    textAlign: 'center'
  },
  input: {
    backgroundColor: '#F2F5F7',
    borderRadius: 4,
    fontSize: 14,
    fontWeight: '500',
    height: 50,
    marginBottom: 15,
    paddingHorizontal: 10,
    opacity: 1.0,
  },
  label: {
    color: '#464A53',
    fontWeight: '500',
    marginTop: 15,
    textAlign: 'center'
  },
  multilineInput: {
    backgroundColor: '#F2F5F7',
    borderRadius: 4,
    fontSize: 14,
    fontWeight: '500',
    height: 100,
    marginBottom: 15,
    paddingHorizontal: 10,
    opacity: 1.0,
  },
  thumbnailStyle: {
    margin: 5,
    borderRadius: 4,
    width: 75,
    height: 125,
  }
});
